@@ -88,7 +88,7 @@ class ListQuota(neutronV20.NeutronCommand, lister.Lister):
             info = data[collection]
         _columns = len(info) > 0 and sorted(info[0].keys()) or []
         return (_columns, (utils.get_item_properties(s, _columns)
-                for s in info))
+                           for s in info))
 
 
 class ShowQuotaBase(neutronV20.NeutronCommand, show.ShowOne):
@@ -140,7 +140,7 @@ class ShowQuotaDefault(ShowQuotaBase):
 
 
 class UpdateQuota(neutronV20.NeutronCommand, show.ShowOne):
-    """Define tenant's quotas not to use defaults."""
+    """Update a given tenant's quotas."""
 
     resource = 'quota'
 
